/*************************************************************************

      Graphics Research Group - Department of Computer Science
                  University of Sheffield, UK
               Michael Meredith & Steve Maddock
                     Copyright (c) 2010
                    All Rights Reserved.


  Permission is hereby granted, free of charge, to use this software 
  and its documentation without restriction, including without limitation 
  the rights to use, copy, modify, merge and publish, subject to the following 
  conditions:

   1. The code must retain the above copyright notice, this list of
      conditions and the following disclaimer.

   2. Any modifications must be clearly marked as such.

   3. Original authors' names are not deleted.

   4. The authors' names are not used to endorse or promote products
      derived from this software without specific prior written
      permission from the author.

   5. This software is used in a research, non-profit capacity only and not 
      for commercial or profit applications unless specific prior written
      permission from the author is given.


  THE UNIVERSITY OF SHEFFIELD AND THE CONTRIBUTORS TO THIS WORK
  DISCLAIM ALL WARRANTIES WITH REGARD TO THIS SOFTWARE, INCLUDING
  ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS, IN NO EVENT
  SHALL THE UNIVERSITY OF SHEFFIELD NOR THE CONTRIBUTORS BE LIABLE
  FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN
  AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
  THIS SOFTWARE.

*************************************************************************/

public class MocapData
{
  private int noofframes;
  private float framerate;    // frames per second
  private Node root;
  private Node[] nodes;
  
  public MocapData()
  {
  }
  
  public int getNoOfNodes()
  {
    return (nodes==null?0:nodes.length);
  }
  
  public int getNoOfFrames()
  {
    return noofframes;
  }
  
  public void setNoOfFrames(int frames)
  {
    this.noofframes=frames;
  }
  
  public float getFrameRate()
  {
    return framerate;
  }
  
  public void setFrameRate(float fps)
  {
    framerate=fps;
  }

  public Node getRoot()
  {
    return root;
  }
  
  public void setRoot(Node root)
  {
    this.root=root;
  }
  
  public Node getNode(int index)
  {
    if (index<getNoOfNodes())
      return nodes[index];
    else
      return null;
  }
  
  public Node addNode(Node node)
  {
    int len=getNoOfNodes();
    Node[] tmp=new Node[len+1];
    for (int i=0; i<len; i++)
      tmp[i]=nodes[i];
    nodes=tmp;
    nodes[len]=node;
    return node;
  }
  
  public String toString()
  {
    String res="Frames="+noofframes+"; fps="+framerate+"\r\n";
    if (root!=null)
      return res+root.getHierarchy(1);
    else
      return res;
  }

}